/*--------------------------------------------------------------------------------------------------

  Name         :  NokiaLCD.h

  Description  :  Header file for Nokia 84x48 graphic LCD driver.

  Author       :  2003-03-08 - Louis Frigon.

  History      :  2003-03-08 - First release.

--------------------------------------------------------------------------------------------------*/
#ifndef _NOKIALCD_H_

#define _NOKIALCD_H_

/*--------------------------------------------------------------------------------------------------
                                  General purpose constants
--------------------------------------------------------------------------------------------------*/
//#define NULL                       0
#define LCDFALSE                      0
#define LCDTRUE                       1

#define LCD_X_RES                  84
#define LCD_Y_RES                  48

//  port A pinout for LCD.
#define LCD_DC_PIN                 1<<4  //  PA23
#define LCD_CE_PIN                 1<<1  //  PA27
#define LCD_MOSI_PIN               1<<6  //  PA08
#define LCD_RST_PIN                1<<3  //  PA28
#define LCD_CLK_PIN                1<<5  //  PA07


#define LCD_MASK ((LCD_DC_PIN)|(LCD_CE_PIN)|(LCD_MOSI_PIN)|(LCD_RST_PIN)|(LCD_CLK_PIN))

//#define LED1            (1<<0)  /* PA0 / PGMEN0 & PWM0 TIOA0  48 */
//#define LED2            (1<<1)  /* PA1 / PGMEN1 & PWM1 TIOB0  47 */
//#define LED3            (1<<2)  /* PA2          & PWM2 SCK0   44 */
//#define LED4            (1<<3)  /* PA3          & TWD  NPCS3  43 */
//#define NB_LEB                  4

//#define LDAC            (1<<26) // PA26 - LDAC signal for external DAC

//#define LED_MASK        (LED1|LED2|LED3|LED4)



#define LCD_CACHE_SIZE             ((LCD_X_RES * LCD_Y_RES) / 8)

/*--------------------------------------------------------------------------------------------------
                                       Type definitions
--------------------------------------------------------------------------------------------------*/
typedef char                       bool;
typedef unsigned char              byte;
typedef unsigned int               word;

typedef enum
{
    LCD_CMD  = 0,
    LCD_DATA = 1

} LcdCmdData;

typedef enum
{
    PIXEL_OFF =  0,
    PIXEL_ON  =  1,
    PIXEL_XOR =  2

} LcdPixelMode;

typedef enum
{
    FONT_1X = 1,
    FONT_2X = 2

} LcdFontSize;

/*--------------------------------------------------------------------------------------------------
                                 Public function prototypes
--------------------------------------------------------------------------------------------------*/
void LcdInvertStr(unsigned char num);//argussoft function

void LcdInit       ( void );
void LcdClear      ( void );
void LcdUpdate     ( void );
void LcdGotoXY     ( byte x, byte y );
void LcdChr        ( LcdFontSize size, byte ch );
void LcdStr        ( LcdFontSize size, byte *dataPtr );
void LcdPixel      ( byte x, byte y, LcdPixelMode mode );
void LcdLine       ( byte x1, byte y1, byte x2, byte y2, LcdPixelMode mode );

#endif  //  _NOKIALCD_H_
/*--------------------------------------------------------------------------------------------------
                                         End of file.
--------------------------------------------------------------------------------------------------*/



